Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS CodeDeploy.

Actions, resources, and condition keys for AWS CodeDeploy - Service Authorization Reference

# Actions, resources, and condition keys for AWS CodeDeploy

AWS CodeDeploy (service prefix: `codedeploy` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS CodeDeploy
- Resource types defined by AWS CodeDeploy
- Condition keys for AWS CodeDeploy

## Actions defined by AWS CodeDeploy

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AddTagsToOnPremisesInstances | Grants permission to add tags to one or more on-premises instances | Tagging | instance* |  |
BatchGetApplicationRevisions | Grants permission to get information about one or more application revisions | Read | application* |  |
BatchGetApplications | Grants permission to get information about multiple applications associated with the IAM user | Read | application* |  |
BatchGetDeploymentGroups | Grants permission to get information about one or more deployment groups | Read | deploymentgroup* |  |
BatchGetDeploymentInstances | Grants permission to get information about one or more instance that are part of a deployment group | Read | deploymentgroup* |  |
BatchGetDeploymentTargets | Grants permission to return an array of one or more targets associated with a deployment. This method works with all compute types and should be used instead of the deprecated BatchGetDeploymentInstances. The maximum number of targets that can be returned is 25 | Read |  |  |
BatchGetDeployments | Grants permission to get information about multiple deployments associated with the IAM user | Read | deploymentgroup* |  |
BatchGetOnPremisesInstances | Grants permission to get information about one or more on-premises instances | Read | instance* |  |
ContinueDeployment | Grants permission to start the process of rerouting traffic from instances in the original environment to instances in thereplacement environment without waiting for a specified wait time to elapse | Write |  |  |
CreateApplication | Grants permission to create an application associated with the IAM user | Write | application* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCloudFormationDeployment [permission only] | Grants permission to create CloudFormation deployment to cooperate ochestration for a CloudFormation stack update | Write |  |  |
CreateDeployment | Grants permission to create a deployment for an application associated with the IAM user | Write | deploymentgroup* |  |
CreateDeploymentConfig | Grants permission to create a custom deployment configuration associated with the IAM user | Write | deploymentconfig* |  |
CreateDeploymentGroup | Grants permission to create a deployment group for an application associated with the IAM user | Write | deploymentgroup* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteApplication | Grants permission to delete an application associated with the IAM user | Write | application* |  |
DeleteDeploymentConfig | Grants permission to delete a custom deployment configuration associated with the IAM user | Write | deploymentconfig* |  |
DeleteDeploymentGroup | Grants permission to delete a deployment group for an application associated with the IAM user | Write | deploymentgroup* |  |
DeleteGitHubAccountToken | Grants permission to delete a GitHub account connection | Write |  |  |
DeleteResourcesByExternalId | Grants permission to delete resources associated with the given external Id | Write |  |  |
DeregisterOnPremisesInstance | Grants permission to deregister an on-premises instance | Write | instance* |  |
GetApplication | Grants permission to get information about a single application associated with the IAM user | List | application* |  |
GetApplicationRevision | Grants permission to get information about a single application revision for an application associated with the IAM user | List | application* |  |
GetDeployment | Grants permission to get information about a single deployment to a deployment group for an application associated with the IAM user | List | deploymentgroup* |  |
GetDeploymentConfig | Grants permission to get information about a single deployment configuration associated with the IAM user | List | deploymentconfig* |  |
GetDeploymentGroup | Grants permission to get information about a single deployment group for an application associated with the IAM user | List | deploymentgroup* |  |
GetDeploymentInstance | Grants permission to get information about a single instance in a deployment associated with the IAM user | List | deploymentgroup* |  |
GetDeploymentTarget | Grants permission to return information about a deployment target | Read |  |  |
GetOnPremisesInstance | Grants permission to get information about a single on-premises instance | List | instance* |  |
ListApplicationRevisions | Grants permission to get information about all application revisions for an application associated with the IAM user | List | application* |  |
ListApplications | Grants permission to get information about all applications associated with the IAM user | List |  |  |
ListDeploymentConfigs | Grants permission to get information about all deployment configurations associated with the IAM user | List |  |  |
ListDeploymentGroups | Grants permission to get information about all deployment groups for an application associated with the IAM user | List | application* |  |
ListDeploymentInstances | Grants permission to get information about all instances in a deployment associated with the IAM user | List | deploymentgroup* |  |
ListDeploymentTargets | Grants permission to return an array of target IDs that are associated a deployment | List |  |  |
ListDeployments | Grants permission to get information about all deployments to a deployment group associated with the IAM user, or to get all deployments associated with the IAM user | List | deploymentgroup* |  |
ListGitHubAccountTokenNames | Grants permission to list the names of stored connections to GitHub accounts | List |  |  |
ListOnPremisesInstances | Grants permission to get a list of one or more on-premises instance names | List |  |  |
ListTagsForResource | Grants permission to return a list of tags for the resource identified by a specified ARN. Tags are used to organize and categorize your CodeDeploy resources | List | application |  |
deploymentgroup |  |
PutLifecycleEventHookExecutionStatus | Grants permission to notify a lifecycle event hook execution status for associated deployment with the IAM user | Write |  |  |
RegisterApplicationRevision | Grants permission to register information about an application revision for an application associated with the IAM user | Write | application* |  |
RegisterOnPremisesInstance | Grants permission to register an on-premises instance | Write | instance* |  |
RemoveTagsFromOnPremisesInstances | Grants permission to remove tags from one or more on-premises instances | Tagging | instance* |  |
SkipWaitTimeForInstanceTermination | Grants permission to override any specified wait time and starts terminating instances immediately after the traffic routing is complete. This action applies to blue-green deployments only | Write |  |  |
StopDeployment | Grants permission to stop a deployment | Write |  |  |
TagResource | Grants permission to associate the list of tags in the input Tags parameter with the resource identified by the ResourceArn input parameter | Tagging | application |  |
deploymentgroup |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to disassociate a resource from a list of tags. The resource is identified by the ResourceArn input parameter. The tags are identfied by the list of keys in the TagKeys input parameter | Tagging | application |  |
deploymentgroup |  |
| aws:TagKeys |
UpdateApplication | Grants permission to update an application | Write | application* |  |
UpdateDeploymentGroup | Grants permission to change information about a single deployment group for an application associated with the IAM user | Write | deploymentgroup* |  |

## Resource types defined by AWS CodeDeploy

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
application | `arn:$ { Partition}:codedeploy:$ { Region}:$ { Account}:application:$ { ApplicationName}` |
deploymentconfig | `arn:$ { Partition}:codedeploy:$ { Region}:$ { Account}:deploymentconfig:$ { DeploymentConfigurationName}` |
deploymentgroup | `arn:$ { Partition}:codedeploy:$ { Region}:$ { Account}:deploymentgroup:$ { ApplicationName}/$ { DeploymentGroupName}` |
instance | `arn:$ { Partition}:codedeploy:$ { Region}:$ { Account}:instance:$ { InstanceName}` |

## Condition keys for AWS CodeDeploy

AWS CodeDeploy defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.